Learn R Programming

latenetwork (version 1.0.1)

datageneration: Generate Artificial Data by Simulation

Description

The datageneration() function generates artificial ring-network data by simulation. The function is used in the package vignette.

Usage

datageneration(n)

Value

A list containing the outcome vector, the treatment vector, the instrumental vector, and the true instrumental exposure vector, and the symmetric binary adjacency matrix.

Arguments

n

The sample size

Examples

Run this code
latenetwork::datageneration(n = 2000)

Run the code above in your browser using DataLab