datageneration: Generate Artificial Data by Simulation
Description
The datageneration() function generates artificial ring-network data
by simulation.
The function is used in the package vignette.
Usage
datageneration(n)
Value
A list containing the outcome vector, the treatment vector,
the instrumental vector, and the true instrumental exposure vector, and
the symmetric binary adjacency matrix.